aboutsummaryrefslogtreecommitdiffstatshomepage
path: root/mandoc.h
diff options
context:
space:
mode:
Diffstat (limited to 'mandoc.h')
-rw-r--r--mandoc.h9
1 files changed, 6 insertions, 3 deletions
diff --git a/mandoc.h b/mandoc.h
index 7a2a9668..502777e0 100644
--- a/mandoc.h
+++ b/mandoc.h
@@ -1,4 +1,4 @@
-/* $Id: mandoc.h,v 1.91 2011/07/22 14:55:07 kristaps Exp $ */
+/* $Id: mandoc.h,v 1.92 2011/07/23 12:01:54 kristaps Exp $ */
/*
* Copyright (c) 2010, 2011 Kristaps Dzonsons <kristaps@bsd.lv>
*
@@ -285,7 +285,8 @@ enum eqn_boxt {
EQN_ROOT, /* root of parse tree */
EQN_TEXT, /* text (number, variable, whatever) */
EQN_SUBEXPR, /* nested `eqn' subexpression */
- EQN_LIST /* list of subexpressions */
+ EQN_LIST, /* subexpressions list */
+ EQN_MATRIX /* matrix subexpression */
};
enum eqn_markt {
@@ -324,6 +325,9 @@ enum eqn_pilet {
EQNPILE_CPILE,
EQNPILE_RPILE,
EQNPILE_LPILE,
+ EQNPILE_CCOL,
+ EQNPILE_RCOL,
+ EQNPILE_LCOL,
EQNPILE__MAX
};
@@ -346,7 +350,6 @@ struct eqn_box {
enum eqn_markt mark; /* a mark about the box */
enum eqn_fontt font; /* font of box */
enum eqn_pilet pile; /* equation piling */
- int above; /* next node is above */
};
/*